import { Data, animate, Override, Animatable, FramerAnimation } from "framer";
import * as React from "react";

const data = Data({
  leftPositionBoxA: Animatable(20),
  leftPositionBoxB: Animatable(20),
  goingForward: true,
  currentAnimationBoxA: "linear",
  selectedBoxA: [
    Animatable("#28AFFA"),
    Animatable("#fff"),
    Animatable("#fff"),
    Animatable("#fff"),
    Animatable("#fff"),
    Animatable("#fff"),
    Animatable("#fff")
  ],
  currentAnimationBoxB: "ease",
  selectedBoxB: [
    Animatable("#fff"),
    Animatable("#fff"),
    Animatable("#fff"),
    Animatable("#7DDD11"),
    Animatable("#fff"),
    Animatable("#fff"),
    Animatable("#fff")
  ]
});

export const BoxA: Override = () => {
  return {
    left: data.leftPositionBoxA
  };
};
export const BoxB: Override = () => {
  return {
    left: data.leftPositionBoxB
  };
};

const startAnimations = () => {
  const seconds = 2;
  let animateToPosition = 850;
  if (!data.goingForward) {
    animateToPosition = 20;
  }
  switch (data.currentAnimationBoxA) {
    case "linear":
      animate.linear(data.leftPositionBoxA, animateToPosition, {
        duration: seconds
      });
      break;
    case "easein":
      animate.easeIn(data.leftPositionBoxA, animateToPosition, {
        duration: seconds
      });
      break;
    case "easeout":
      animate.easeOut(data.leftPositionBoxA, animateToPosition, {
        duration: seconds
      });
      break;
    case "ease":
      animate.ease(data.leftPositionBoxA, animateToPosition, {
        duration: seconds
      });
      break;
    case "easeinout":
      animate.easeInOut(data.leftPositionBoxA, animateToPosition, {
        duration: seconds
      });
      break;
    case "bezier":
      animate.bezier(data.leftPositionBoxA, animateToPosition, {
        duration: 2,
        curve: [1, -0.65, 0, 1.25]
      });
      break;
    case "spring":
      animate.spring(data.leftPositionBoxA, animateToPosition, {
        duration: 2,
        dampingRatio: 0.5
      });
      break;
  }
  // Not using async / await, because it doesn't work well with spring animations
  setTimeout(() => {
    data.goingForward = !data.goingForward;
  }, 2000);
};

const makeButtonSelected = (forBoxA, index) => {
  if (forBoxA) {
    data.selectedBoxA.forEach(cirleBackground => {
      cirleBackground.set("#fff");
    });
    data.selectedBoxA[index].set("#28AFFA");
  } else {
  }
};

export const Button_BoxA_Linear: Override = props => {
  return {
    onTap() {
      makeButtonSelected(true, 0);
      data.currentAnimationBoxA = "linear";
      startAnimations();
    }
  };
};
export const Button_BoxA_Linear_Dot: Override = props => {
  return {
    background: data.selectedBoxA[0]
  };
};

export const Button_BoxA_EaseIn: Override = () => {
  return {
    onTap() {
      makeButtonSelected(true, 1);
      data.currentAnimationBoxA = "easein";
      startAnimations();
    }
  };
};
export const Button_BoxA_EaseIn_Dot: Override = props => {
  return {
    background: data.selectedBoxA[1]
  };
};

export const Button_BoxA_EaseOut: Override = () => {
  return {
    onTap() {
      makeButtonSelected(true, 2);
      data.currentAnimationBoxA = "easeout";
      startAnimations();
    }
  };
};
export const Button_BoxA_EaseOut_Dot: Override = props => {
  return {
    background: data.selectedBoxA[2]
  };
};

export const Button_BoxA_Ease: Override = () => {
  return {
    onTap() {
      makeButtonSelected(true, 3);
      data.currentAnimationBoxA = "ease";
      startAnimations();
    }
  };
};
export const Button_BoxA_Ease_Dot: Override = props => {
  return {
    background: data.selectedBoxA[3]
  };
};

export const Button_BoxA_EaseInOut: Override = () => {
  return {
    onTap() {
      makeButtonSelected(true, 4);
      data.currentAnimationBoxA = "easeinout";
      startAnimations();
    }
  };
};
export const Button_BoxA_EaseInOut_Dot: Override = props => {
  return {
    background: data.selectedBoxA[4]
  };
};

export const Button_BoxA_Bezier: Override = () => {
  return {
    onTap() {
      makeButtonSelected(true, 5);
      data.currentAnimationBoxA = "bezier";
      startAnimations();
    }
  };
};
export const Button_BoxA_Bezier_Dot: Override = props => {
  return {
    background: data.selectedBoxA[5]
  };
};

export const Button_BoxA_Spring: Override = () => {
  return {
    onTap() {
      makeButtonSelected(true, 6);
      data.currentAnimationBoxA = "spring";
      startAnimations();
    }
  };
};
export const Button_BoxA_Spring_Dot: Override = props => {
  return {
    background: data.selectedBoxA[6]
  };
};

export const Button_BoxB_Linear: Override = props => {
  return {
    onTap() {
      makeButtonSelected(true, 0);
      data.currentAnimationBoxB = "linear";
      startAnimations();
    }
  };
};
export const Button_BoxB_Linear_Dot: Override = props => {
  return {
    background: data.selectedBoxB[0]
  };
};

export const Button_BoxB_EaseIn: Override = () => {
  return {
    onTap() {
      makeButtonSelected(true, 1);
      data.currentAnimationBoxB = "easein";
      startAnimations();
    }
  };
};
export const Button_BoxB_EaseIn_Dot: Override = props => {
  return {
    background: data.selectedBoxB[1]
  };
};

export const Button_BoxB_EaseOut: Override = () => {
  return {
    onTap() {
      makeButtonSelected(true, 2);
      data.currentAnimationBoxB = "easeout";
      startAnimations();
    }
  };
};
export const Button_BoxB_EaseOut_Dot: Override = props => {
  return {
    background: data.selectedBoxB[2]
  };
};

export const Button_BoxB_Ease: Override = () => {
  return {
    onTap() {
      makeButtonSelected(true, 3);
      data.currentAnimationBoxB = "ease";
      startAnimations();
    }
  };
};
export const Button_BoxB_Ease_Dot: Override = props => {
  return {
    background: data.selectedBoxB[3]
  };
};

export const Button_BoxB_EaseInOut: Override = () => {
  return {
    onTap() {
      makeButtonSelected(true, 4);
      data.currentAnimationBoxB = "easeinout";
      startAnimations();
    }
  };
};
export const Button_BoxB_EaseInOut_Dot: Override = props => {
  return {
    background: data.selectedBoxB[4]
  };
};

export const Button_BoxB_Bezier: Override = () => {
  return {
    onTap() {
      makeButtonSelected(true, 5);
      data.currentAnimationBoxB = "bezier";
      startAnimations();
    }
  };
};
export const Button_BoxB_Bezier_Dot: Override = props => {
  return {
    background: data.selectedBoxB[5]
  };
};

export const Button_BoxB_Spring: Override = () => {
  return {
    onTap() {
      makeButtonSelected(true, 6);
      data.currentAnimationBoxB = "spring";
      startAnimations();
    }
  };
};
export const Button_BoxB_Spring_Dot: Override = props => {
  return {
    background: data.selectedBoxB[6]
  };
};
