import { Data, animate, Override, Animatable, FramerAnimation } from "framer";
import * as React from "react";

const data = Data({
  leftPositionBoxA: Animatable(20),
  leftPositionBoxB: Animatable(20),
  goingForward: true,
  currentAnimationBoxA: "linear",
  currentAnimationBoxB: "ease",
  selectedBoxA: [
    Animatable("#fff"),
    Animatable("#fff"),
    Animatable("#fff"),
    Animatable("#fff"),
    Animatable("#fff"),
    Animatable("#fff")
  ]
});

export const BoxA: Override = () => {
  return {
    left: data.leftPositionBoxA
  };
};
export const BoxB: Override = () => {
  return {
    left: data.leftPositionBoxB
  };
};

const startAnimations = () => {
  const seconds = 2;
  let animateToPosition = 850;
  if (!data.goingForward) {
    animateToPosition = 20;
  }
  switch (data.currentAnimationBoxA) {
    case "linear":
      animate.linear(data.leftPositionBoxA, animateToPosition, {
        duration: seconds
      });
      break;
    case "easein":
      animate.easeIn(data.leftPositionBoxA, animateToPosition, {
        duration: seconds
      });
      break;
    case "easeout":
      animate.easeOut(data.leftPositionBoxA, animateToPosition, {
        duration: seconds
      });
      break;
    case "ease":
      animate.ease(data.leftPositionBoxA, animateToPosition, {
        duration: seconds
      });
      break;
    case "easeinout":
      animate.easeInOut(data.leftPositionBoxA, animateToPosition, {
        duration: seconds
      });
      break;
    case "bezier":
      animate.bezier(data.leftPositionBoxA, animateToPosition, {
        duration: 2,
        curve: [1, -0.65, 0, 1.25]
      });
      break;
    case "spring":
      animate.spring(data.leftPositionBoxA, animateToPosition, {
        duration: 2,
        dampingRatio: 0.5
      });
      break;
  }
  // Not using async / await, because it doesn't work well with spring animations
  setTimeout(() => {
    data.goingForward = !data.goingForward;
  }, 2000);
};

const selectButton = number => {
  data.selectedBoxA.forEach(cirleBackground => {
    cirleBackground.set("#fff");
  });
  data.selectedBoxA[number].set("#28AFFA");
};

export const BoxA_SelectLinear: Override = props => {
  return {
    onTap() {
      data.currentAnimationBoxA = "linear";
      startAnimations();
    }
  };
};
export const BoxA_SelectLinear_Circle: Override = props => {
  return {
    background: data.selectedBoxA[0]
  };
};

export const BoxA_SelectEaseIn: Override = () => {
  return {
    onTap() {
      data.currentAnimationBoxA = "easein";
      startAnimations();
    }
  };
};
export const BoxA_SelectEaseIn_Circle: Override = props => {
  return {
    background: data.selectedBoxA[1]
  };
};

export const BoxA_SelectEaseOut: Override = () => {
  return {
    onTap() {
      data.currentAnimationBoxA = "easeout";
      startAnimations();
    }
  };
};
export const BoxA_SelectEase: Override = () => {
  return {
    onTap() {
      data.currentAnimationBoxA = "ease";
      startAnimations();
    }
  };
};
export const BoxA_SelectEaseInOut: Override = () => {
  return {
    onTap() {
      data.currentAnimationBoxA = "easeinout";
      startAnimations();
    }
  };
};
export const BoxA_SelectBezier: Override = () => {
  return {
    onTap() {
      data.currentAnimationBoxA = "bezier";
      startAnimations();
    }
  };
};
export const BoxA_SelectSpring: Override = () => {
  return {
    onTap() {
      data.currentAnimationBoxA = "spring";
      startAnimations();
    }
  };
};
